@@ -1,5 +1,12 @@
 from .dialogs import run_dialog, run
-from .types import dialog, send_message, get_client_response, BaseDialog, Dialog
+from .types import (
+    dialog,
+    send_message,
+    get_client_response,
+    BaseDialog,
+    Dialog,
+    DialogStateException,
+)
 from .dialog_state import DialogState, new_empty_state, state_from_dict, Result
 from .persistence.persistence import PersistenceProvider
 from .persistence.in_memory import InMemoryPersistence
